<?php
/**
 * Dashboard Page
 *
 * @package Aytias
 */

if ( ! class_exists( 'Aytias_Dashboard' ) ) {
	/**
	 * Main class.
	 *
	 * @since 1.0.0
	 */
	class Aytias_Dashboard {

        /**
		 * Theme name.
		 *
		 * @var string $theme_name Theme name.
		 *
		 * @since 1.0.0
		 */
		private $theme_name;

		/**
		 * Theme slug.
		 *
		 * @var string $theme_slug Theme slug.
		 *
		 * @since 1.0.0
		 */
		private $theme_slug;

		/**
		 * Current theme object.
		 *
		 * @var WP_Theme $theme Current theme.
		 */
		private $theme;

        /**
		 * Some globals url
		 */
        private $shop_url = 'https://unfoldwp.com';
        private $doc_url = 'https://docs.unfoldwp.com/docs/aytias';
        private $support_url = 'https://unfoldwp.com/support';
        private $demo_url = 'https://preview.unfoldwp.com/aytias';

        /**
		 * Constructor.
		 *
		 * @since 1.0.0
		 */
        public function __construct() {

            $theme = wp_get_theme();

			if ( is_child_theme() ) {
				$this->theme_name = $theme->parent()->get( 'Name' );
				$this->theme      = $theme->parent();
			} else {
				$this->theme_name = $theme->get( 'Name' );
				$this->theme      = $theme->parent();
			}

			$this->theme_version = $theme->get( 'Version' );
			$this->theme_slug    = $theme->get_template();

            $this->menu_name = sprintf( esc_html__( '%s', 'aytias' ), $this->theme_name );
			$this->page_name = sprintf( esc_html__( '%s', 'aytias' ), $this->theme_name );
            $this->page_slug = $this->theme_slug . '-welcome';
			
            if ( current_user_can( 'manage_options' ) ) {
                add_action( 'admin_menu', array( $this, 'add_menu' ) );
                add_action( 'admin_bar_menu', array( $this, 'add_bar_menu' ), 999 );
                add_action( 'admin_notices', array( $this, 'display_admin_notice' ), 99 );
            }

            add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_scripts' ) );

            add_action( 'wp_ajax_aytias_dismiss', array( $this, 'dismiss_callback' ) );
			add_action( 'wp_ajax_nopriv_aytias_dismiss', array( $this, 'dismiss_callback' ) );
        }

        /**
		 * Add theme dashboard page.
		 *
		 * @since 1.0.0
		 */
        public function add_menu() {

            add_theme_page( 
                $this->menu_name, 
                $this->page_name,
                'manage_options', 
                $this->page_slug, 
                array( $this, 'render_main_page')
            );
        }

        /**
		 * Add link in menu bar
		 *
		 * @since 1.0.0
		 */
        public function add_bar_menu() {

            global $wp_admin_bar;
            if ( ! is_super_admin() || ! is_admin_bar_showing() ) {
                return;
            }
            $wp_admin_bar->add_menu( array(
                'parent' => 'site-name',
                'id'     => $this->page_slug,
                'title'  => $this->theme_name,
                'href'   => admin_url( "themes.php?page=$this->page_slug" )
            ) );
        }

        /**
		 * Display notice in admin area 
		 *
		 * @since 1.0.1
		 */
        public function display_admin_notice(){
            $screen_id = null;
			$current_screen = get_current_screen();
			if ( $current_screen ) {
				$screen_id = $current_screen->id;
			}

			$user_id = get_current_user_id();
			$dismiss_status = get_user_meta( $user_id, 'aytias_dismiss_status', true );
			?>
			<?php if ( current_user_can( 'edit_theme_options' ) && 'themes' === $screen_id && 1 !== absint( $dismiss_status ) ) : ?>
				<div class="aytias-about-notice notice notice-about">
                    <p>
                        <?php echo sprintf( esc_html__( 'Welcome! Thank you for choosing our theme %1$s. To fully take advantage of the best our theme can offer, please make sure you visit theme info page.', 'aytias' ), esc_html( $this->theme_name ) ) ;?>
                    </p>
                    <p>
                        <a href="<?php echo esc_url( admin_url( "themes.php?page=$this->page_slug" ) )?>" class="button button-primary">
                            <?php echo sprintf( esc_html__( 'Get started with %1$s', 'aytias' ), $this->theme_name )?>
                        </a>
                        <a href="#" class="btn-dismiss" data-userid="<?php echo esc_attr( get_current_user_id() );?>" data-nonce="<?php echo esc_attr( wp_create_nonce( 'aytias_dismiss_nonce' ) );?>">
                            <span class="dashicons dashicons-no"></span>
                        </a>
                    </p>
				</div>
			<?php endif; ?>
			<?php
        }

        /**
		 * Dashboard Page
		 *
		 * @since 1.0.0
		 */
        public function render_main_page() {
            
            ?>
            <div class="wrap about-wrap aytias-about-wrap">

                <div class="top-wrapper">
					<a href="<?php echo $this->shop_url;?>" target="_blank"><div class="wp-badge"></div></a>
					<div class="intro-text">
						<h1><?php echo esc_html( $this->theme_name ); ?>&nbsp;-&nbsp;<?php echo esc_html( $this->theme_version ); ?></h1>
                        <p class="about-text">
                            <?php _e('The theme is now installed and ready to use. We want to make sure you have the best experience using the theme and that is why we gathered here all the necessary information for you. Thanks for using our theme!', 'aytias');?>
                        </p>
					</div>
				</div>

                <p class="quick-links">
                    <a href="<?php echo $this->shop_url;?>/products/aytias/" class="button " target="_blank"><?php _e('Theme Details', 'aytias');?></a>
                    <a href="<?php echo $this->demo_url;?>" class="button " target="_blank"><?php _e('View Demo', 'aytias');?></a>
                    <a href="<?php echo $this->doc_url;?>" class="button " target="_blank"><?php _e('View Documentation', 'aytias');?></a>
                </p>

                <?php $current_tab = isset( $_GET['tab'] ) ? wp_unslash( $_GET['tab'] ) : 'getting-started';?>
                <h2 class="nav-tab-wrapper wp-clearfix">
                    <a href="<?php echo esc_url( admin_url( 'themes.php?page=' . $this->page_slug ) ) . '&tab=getting-started'?>" class="nav-tab tab-getting-started <?php echo ($current_tab == 'getting-started') ? ' nav-tab-active' : ''; ?>"><?php _e('Gettting Started', 'aytias'); ?></a>
                    <a href="<?php echo esc_url( admin_url( 'themes.php?page=' . $this->page_slug ) ) . '&tab=recommended-plugins'?>" class="nav-tab tab-recommended-plugins <?php echo ($current_tab == 'recommended-plugins') ? ' nav-tab-active' : ''; ?>"><?php _e('Recommended Plugins', 'aytias'); ?></a>
                </h2>

                <?php 
                $current_tab = isset( $_GET['tab'] ) ? wp_unslash( $_GET['tab'] ) : 'getting-started';
                $method = str_replace( '-', '_', esc_attr( $current_tab ) );
    
                if ( method_exists( $this, $method ) ) {
                    $this->{$method}();
                } else {
                    printf( esc_html__( '%s() method does not exist.', 'aytias' ), $method );
                }
                ?>

            </div><!-- aytias-about-wrap -->
            <?php
        }

        /**
		 * Render getting started.
		 *
		 * @since 1.0.0
		 */
		public function getting_started() {
            global $tgmpa;

            $tgmpa_url = $tgmpa_complete = '';
            if ( $tgmpa ) {
				$tgmpa_url = $tgmpa->get_tgmpa_url();
			    $tgmpa_complete = $tgmpa->is_tgmpa_complete();
			}
            ?>
            <div id="getting-started" class="feature-section aytias-section aytias-section-getting-started">
                <div class="col">
                    <h3>
                        <span class="dashicons dashicons-format-aside"></span>
                        <?php _e('Theme Documentation', 'aytias');?>					
                    </h3>
                    <p><?php _e('Get information on how to setup and customize the theme.', 'aytias');?></p>
                    <a href="<?php echo $this->doc_url;?>" class="button button-primary" target="_blank"><?php _e( 'View Documentation', 'aytias' ); ?></a>
                </div>
                <div class="col">
                    <h3>
                        <span class="dashicons dashicons-admin-customizer"></span>
                        <?php _e('Widget Options', 'aytias');?>					
                    </h3>
                    <p><?php _e('Use any combination of widgets and widgetareas to make your site unique.', 'aytias');?></p>
                    <a href="<?php echo admin_url('widgets.php')?>" class="button button-primary" target="_self"><?php _e( 'Widgets', 'aytias' ); ?></a>
                </div>
                <div class="col">
                    <h3>
                        <span class="dashicons dashicons-admin-customizer"></span>
                        <?php _e('Theme Options', 'aytias');?>					
                    </h3>
                    <p><?php _e('Make sure to check out user friendly extensive customizer settings.', 'aytias');?></p>
                    <a href="<?php echo wp_customize_url(); ?>" class="button button-primary" target="_self"><?php _e( 'Customize', 'aytias' ); ?></a>
                </div>
                <div class="col">
                    <h3>
                        <span class="dashicons dashicons-layout"></span>
                        <?php _e('Demo Content', 'aytias');?>					
                    </h3>
                    <p><?php _e('To import demo content, One Click Demo Import plugin should be installed & activated. After that, visit Import Demo Data menu under Appearance.', 'aytias');?></p>
                    <?php if ( true !== $tgmpa_complete ) : ?>
					    <a href="<?php echo esc_url( $tgmpa_url ); ?>" class="button button-primary"><?php esc_html_e( 'Manage Plugins', 'aytias' ); ?></a>
				    <?php endif; ?>
                </div>
                <div class="col">
                    <h3>
                        <span class="dashicons dashicons-welcome-view-site"></span>
                        <?php _e('Theme Preview', 'aytias');?>					
                    </h3>
                    <p><?php _e('Check out the theme previews for reference to find out what you can achieve using the theme and how it can be customized.', 'aytias');?></p>
                    <a href="<?php echo $this->demo_url;?>" class="button button-primary" target="_blank"><?php _e('View Demos', 'aytias');?></a>
                </div>
                <div class="col">
                    <h3>
                        <span class="dashicons dashicons-sos"></span>
                        <?php _e('Contact Support', 'aytias');?>					
                    </h3>
                    <p><?php _e('Got theme support question or found bug or got some feedbacks? Best place to ask your query is the dedicated Support forum for the theme.', 'aytias');?></p>
                    <a href="<?php echo $this->support_url;?>" class="button button-primary" target="_blank"><?php _e('Contact Support', 'aytias');?></a>
                </div>
            </div>
        <?php
		}

        /**
		 * Render Recommended plugins.
		 *
		 * @since 1.0.0
		 */
		public function recommended_plugins() {

			global $tgmpa;

			if ( ! $tgmpa ) {
				return;
			}

			$tgmpa_url      = $tgmpa->get_tgmpa_url();
			$tgmpa_complete = $tgmpa->is_tgmpa_complete();
			$plugins        = $tgmpa->plugins;
			?>

			<div class="aytias-section aytias-section-useful-plugins">

                <div class="plugins-content">
                    <p><?php _e('Theme supports some helpful WordPress plugins to enhance your site. But, please enable only those plugins which you need in your site. For example, enable WooCommerce only if you are using e-commerce.', 'aytias');?></p>
                </div>

				<?php if ( true !== $tgmpa_complete ) : ?>
					<a href="<?php echo esc_url( $tgmpa_url ); ?>" class="button button-primary"><?php esc_html_e( 'Manage Plugins', 'aytias' ); ?></a>
				<?php endif; ?>

				<?php if ( ! empty( $plugins ) ) : ?>
					<ul class="plugin-list">
						<?php foreach ( $plugins as $plugin ) : ?>
							<li><?php echo esc_html( $plugin['name'] ); ?></li>
						<?php endforeach; ?>
					</ul><!-- .plugin-list -->
				<?php endif; ?>

			</div><!-- .aytias-section -->
			<?php
		}

        /**
         * Enqueue scripts for dashboard page.
         *
         * @since 1.0.0
         * 
         * @param string $hook Page hook.
         */
        public function enqueue_scripts( $hook ) {

            $valid_pages = array(
                "themes.php",
                "toplevel_page_$this->page_slug",
                "appearance_page_$this->page_slug",
            );

            if ( in_array( $hook, $valid_pages, true ) ) {
                
                wp_enqueue_media();
                wp_enqueue_style( "aytias-dashboard-style", get_template_directory_uri() . '/inc/dashboard/css/style.css', array(), $this->theme_version );
                wp_enqueue_script( "aytias-dashboard-script", get_template_directory_uri() . '/inc/dashboard/js/script.js', array( 'jquery' ), $this->theme_version, true );
    
                $localize_script = array(
                    'ajaxUrl' => admin_url( 'admin-ajax.php' ),
                    'nonce'   => wp_create_nonce( 'ajax-nonce' ),
                    'domain'  => get_home_url( '/' )
                );
                wp_localize_script( "aytias-dashboard-script", 'UNFOLDDASHBOARD', $localize_script );
            }
        }

        /**
		 * Callback for AJAX dismiss.
		 *
		 * @since 1.0.1
		 */
		public function dismiss_callback() {

			$output = array();
			$output['status'] = false;

			$userid  = ( isset( $_GET['userid'] ) ) ? esc_attr( wp_unslash( $_GET['userid'] ) ) : '';
			$wpnonce = ( isset( $_GET['_wpnonce'] ) ) ? esc_attr( wp_unslash( $_GET['_wpnonce'] ) ) : '';

			if ( false === wp_verify_nonce( $wpnonce, 'aytias_dismiss_nonce' ) ) {
				wp_send_json( $output );
			}

			update_user_meta( $userid, 'aytias_dismiss_status', 1 );

			$output['status'] = true;

			wp_send_json( $output );
		}

    }
}